@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2012 Mirai Solutions GmbH
+# Copyright (C) 2010-2013 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@
 #############################################################################
 
 setGeneric("setCellStyle",
-		function(object, sheet, row, col, cellstyle) standardGeneric("setCellStyle"))
+		function(object, formula, sheet, row, col, cellstyle) standardGeneric("setCellStyle"))
 
 setMethod("setCellStyle", 
-		signature(object = "workbook", sheet = "numeric"), 
-		function(object, sheet, row, col, cellstyle) {
+		signature(object = "workbook", formula = "missing", sheet = "numeric"), 
+		function(object, formula, sheet, row, col, cellstyle) {
 			xlcCall(object, "setCellStyle", as.integer(sheet - 1), as.integer(row - 1),
 				as.integer(col - 1), cellstyle)
 			invisible()
@@ -39,10 +39,18 @@ setMethod("setCellStyle",
 )
 
 setMethod("setCellStyle", 
-		signature(object = "workbook", sheet = "character"), 
-		function(object, sheet, row, col, cellstyle) {
+		signature(object = "workbook", formula = "missing", sheet = "character"), 
+		function(object, formula, sheet, row, col, cellstyle) {
 			xlcCall(object, "setCellStyle", sheet, as.integer(row - 1),
 					as.integer(col - 1), cellstyle)
 			invisible()
 		}
 )
+
+setMethod("setCellStyle",
+    signature(object = "workbook", formula = "character", sheet = "missing"),
+    function(object, formula, sheet, row, col, cellstyle) {
+      xlcCall(object, "setCellStyle", formula, cellstyle)
+      invisible()
+    }
+)
